@@ -10,18 +10,18 @@ beta.reg <- function(target, dataset, wei = NULL) {
   } else {
     x <- model.matrix(target ~ ., data.frame(dataset) )
     iniphi <- log( sum( target * (1 - target) ) / Rfast::Var(target) / n )
+    oop <- options(warn = -1) 
+    on.exit( options(oop) )
   
     if ( is.null(wei) ) {
       ly1 <- log(1 - target)     ;    ly <- log(target) - ly1           
       sly1 <- sum(ly1)      ;    sly2 <- sum( log(target) ) + sly1   
-      options(warn = -1)
       mod1 <- nlm(regbeta, c( iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, n = n, iterlim = 10000 )
       mod2 <- nlm(regbeta, mod1$estimate, ly = ly, sly1 = sly1, x = x, n = n, iterlim = 10000 )
     } else {
       w <- wei / sum(wei)
       ly1 <- w * log(1 - target)     ;    ly <- w * log(target) - ly1
       sly1 <- sum(ly1)    ;    sly2 <- sum( w * log( target ) ) + sly1   
-      options(warn = -1)
       mod1 <- nlm(regbetawei, c(iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
       mod2 <- nlm(regbetawei, mod1$estimate, ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
     }
