@@ -84,32 +84,32 @@ testIndGLMMNormLog <- function(target, reps = NULL, group, dataset, xIndex, csIn
       return(results);
     }
     if ( is.null(reps) ) {
-      fit1 <- lme4::glmer( target ~ (1|group), weights = wei, family = gaussian(log) ) 
-      fit2 <- lme4::glmer( target ~ (1|group) + x, weights = wei, family = gaussian(log) ) 
+      fit1 <- lme4::glmer( target ~ (1|group), weights = wei, family = gaussian(log), nAGQ = 0 ) 
+      fit2 <- lme4::glmer( target ~ (1|group) + x, weights = wei, family = gaussian(log), nAGQ = 0 ) 
     } else {
       reps <- reps 
       if ( slopes ) {
-        fit1 <- lme4::glmer( target ~ reps + (reps|group), weights = wei, family = gaussian(log) ) 
-        fit2 <- lme4::glmer( target ~ reps + (reps|group) + x, weights = wei, family = gaussian(log) ) 
+        fit1 <- lme4::glmer( target ~ reps + (reps|group), weights = wei, family = gaussian(log), nAGQ = 0 ) 
+        fit2 <- lme4::glmer( target ~ reps + (reps|group) + x, weights = wei, family = gaussian(log), nAGQ = 0 ) 
       } else {
         reps <- reps 
-        fit1 <- lme4::glmer( target ~ reps + (1|group), weights = wei, family = gaussian(log) )  
-        fit2 <- lme4::glmer( target ~ reps + (1|group) + x, weights = wei, family = gaussian(log) )  
+        fit1 <- lme4::glmer( target ~ reps + (1|group), weights = wei, family = gaussian(log), nAGQ = 0 )  
+        fit2 <- lme4::glmer( target ~ reps + (1|group) + x, weights = wei, family = gaussian(log), nAGQ = 0 )  
       }
     }
     
   } else {
     if ( is.null(reps) ) {
-      fit1 <- lme4::glmer( target ~ (1|group) + cs, weights = wei, family = gaussian(log) )    
-      fit2 <- lme4::glmer( target ~ (1|group) + cs+ x, weights = wei, family = gaussian(log) )    
+      fit1 <- lme4::glmer( target ~ (1|group) + cs, weights = wei, family = gaussian(log), nAGQ = 0 )    
+      fit2 <- lme4::glmer( target ~ (1|group) + cs+ x, weights = wei, family = gaussian(log), nAGQ = 0 )    
     } else {
       reps <- reps 
       if (slopes ) {
-        fit1 <- lme4::glmer( target ~ reps + (reps|group) + cs, weights = wei, family = gaussian(log))
-        fit2 <- lme4::glmer( target ~ reps + (reps|group) + cs + x, weights = wei, family = gaussian(log) )
+        fit1 <- lme4::glmer( target ~ reps + (reps|group) + cs, weights = wei, family = gaussian(log), nAGQ = 0 )
+        fit2 <- lme4::glmer( target ~ reps + (reps|group) + cs + x, weights = wei, family = gaussian(log), nAGQ = 0 )
       } else {
-        fit1 <- lme4::glmer( target ~ reps + (1|group) + cs, weights = wei, family = gaussian(log)) 
-        fit2 <- lme4::glmer( target ~ reps + (1|group) + cs + x, weights = wei, family = gaussian(log) ) 
+        fit1 <- lme4::glmer( target ~ reps + (1|group) + cs, weights = wei, family = gaussian(log), nAGQ = 0 ) 
+        fit2 <- lme4::glmer( target ~ reps + (1|group) + cs + x, weights = wei, family = gaussian(log), nAGQ = 0 ) 
       }
     }  
   }
