@@ -85,32 +85,32 @@ testIndGLMMPois = function(target, reps = NULL, group, dataset, xIndex, csIndex,
       return(results);
     }
    if ( is.null(reps) ) {
-     fit1 <- lme4::glmer( target ~ (1|group), weights = wei, family = poisson ) 
-     fit2 <- lme4::glmer( target ~ (1|group) + dataset[, xIndex], weights = wei, family = poisson ) 
+     fit1 <- lme4::glmer( target ~ (1|group), weights = wei, family = poisson, nAGQ = 0 ) 
+     fit2 <- lme4::glmer( target ~ (1|group) + dataset[, xIndex], weights = wei, family = poisson, nAGQ = 0 ) 
    } else {
       reps <- reps 
       if ( slopes ) {
-        fit1 <- lme4::glmer( target ~ reps + (reps|group), weights = wei, family = poisson ) 
-        fit2 <- lme4::glmer( target ~ reps + (reps|group) + x, weights = wei, family = poisson ) 
+        fit1 <- lme4::glmer( target ~ reps + (reps|group), weights = wei, family = poisson, nAGQ = 0 ) 
+        fit2 <- lme4::glmer( target ~ reps + (reps|group) + x, weights = wei, family = poisson, nAGQ = 0 ) 
       } else {
         reps <- reps 
-        fit1 <- lme4::glmer( target ~ reps + (1|group), weights = wei, family = poisson )  
-        fit2 <- lme4::glmer( target ~ reps + (1|group) + x, weights = wei, family = poisson )  
+        fit1 <- lme4::glmer( target ~ reps + (1|group), weights = wei, family = poisson, nAGQ = 0 )  
+        fit2 <- lme4::glmer( target ~ reps + (1|group) + x, weights = wei, family = poisson, nAGQ = 0 )  
       }
    }
    
   } else {
     if ( is.null(reps) ) {
-      fit1 <- lme4::glmer( target ~ (1|group) + cs, weights = wei, family = poisson )    
-      fit2 <- lme4::glmer( target ~ (1|group) + cs + x, weights = wei, family = poisson )    
+      fit1 <- lme4::glmer( target ~ (1|group) + cs, weights = wei, family = poisson, nAGQ = 0 )    
+      fit2 <- lme4::glmer( target ~ (1|group) + cs + x, weights = wei, family = poisson, nAGQ = 0 )    
     } else {
       reps <- reps 
       if (slopes ) {
-        fit1 <- lme4::glmer( target ~ reps + (reps|group) + cs, weights = wei, family = poisson )
-        fit2 <- lme4::glmer( target ~ reps + (reps|group) + cs + x, weights = wei, family = poisson )
+        fit1 <- lme4::glmer( target ~ reps + (reps|group) + cs, weights = wei, family = poisson, nAGQ = 0 )
+        fit2 <- lme4::glmer( target ~ reps + (reps|group) + cs + x, weights = wei, family = poisson, nAGQ = 0)
       } else {
-        fit1 <- lme4::glmer( target ~ reps + (1|group) + cs, weights = wei, family = poisson ) 
-        fit2 <- lme4::glmer( target ~ reps + (1|group) + cs + x, weights = wei, family = poisson ) 
+        fit1 <- lme4::glmer( target ~ reps + (1|group) + cs, weights = wei, family = poisson, nAGQ = 0 ) 
+        fit2 <- lme4::glmer( target ~ reps + (1|group) + cs + x, weights = wei, family = poisson, nAGQ = 0 ) 
       }
     }  
   }
