@@ -18,25 +18,25 @@ testIndTobit = function(target, dataset, xIndex, csIndex, wei = NULL, univariate
   pvalue = log(1);
   stat = 0;
   results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
-  tob = NULL;
-  tob_full = NULL;
+  tob <- NULL;
+  tob_full <- NULL;
   #if the censored indicator is empty, a dummy variable is created
   if  ( length(csIndex) == 0 || sum(csIndex == 0, na.rm = TRUE) > 0 ) {
     tob <- survival::survreg(target ~ ., data = as.data.frame( dataset[, xIndex] ), weights = wei, dist = "gaussian")
     dof <- length( coef(tob) ) - 1
-    stat = 2 * abs( diff(tob$loglik) )
-    pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE);
+    stat <- 2 * abs( diff(tob$loglik) )
+    pvalue <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE);
   } else {
     tob <- survival::survreg(target ~ ., data = as.data.frame( dataset[, csIndex] ), weights = wei, dist = "gaussian") 
     tob_full <- survival::survreg(target ~ ., data = as.data.frame(  dataset[, c(csIndex, xIndex)] ), weights = wei, dist = "gaussian")
-    res = anova(tob, tob_full)
-    stat = res[2, 6] ;
-    dF = res[2, 5];
+    res <- anova(tob, tob_full)
+    stat <- res[2, 6] ;
+    dF <- res[2, 5];
     pvalue = pchisq(stat, dF, lower.tail = FALSE, log.p = TRUE)
   }  
   if ( is.na(pvalue) || is.na(stat) ) {
-    pvalue = log(1);
-    stat = 0;
+    pvalue <- log(1);
+    stat <- 0;
   } else {
     #update hash objects
     if( hash )  {
@@ -44,8 +44,6 @@ testIndTobit = function(target, dataset, xIndex, csIndex, wei = NULL, univariate
       pvalue_hash[key] <- pvalue;     #.set(pvalue_hash , key , pvalue)
     }
   }
-  #testerrorcaseintrycatch(4);
   results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
-  
 }
