@@ -81,7 +81,7 @@ wald.ses <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
       } else   stop('Target must be a factor, vector or a Surv object');
     }
     #available conditional independence tests
-    av_tests = c("waldBeta", "waldCR", "waldWR", "waldER", "waldClogit", "waldLogistic", "waldPois", "waldNB", 
+    av_tests = c("waldBeta", "waldCR", "waldWR", "waldER", "waldLLR", "waldClogit", "waldLogistic", "waldPois", "waldNB", 
                  "waldBinom", "auto", "waldZIP", "waldMMReg", "waldIGreg", "waldOrdinal", "waldGamma", 
 				 "waldNormLog", "waldTobit", "waldQPois", "waldQBinom", NULL);
     ci_test = test
@@ -125,6 +125,9 @@ wald.ses <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
       } else if (test == "waldER") {
         test = waldER;
         
+      } else if (test == "waldLLR") {
+        test = waldLLR;
+        
       } else if (test == "waldBinom") {
         test = waldBinom;
         
